@@ -1,11 +1,11 @@
-/* 
+/*
     This file is part of Rocs.
     Copyright 2008-2009  Tomaz Canabrava <tomaz.canabrava@gmail.com>
     Copyright 2008       Ugo Sangiori <ugorox@gmail.com>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of 
+    published by the Free Software Foundation; either version 2 of
     the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -22,10 +22,11 @@
 
 #include <QWidget>
 
-class Separator : public QWidget {
+class Separator : public QWidget
+{
 public:
-    Separator ( QWidget* parent );
+    Separator(QWidget* parent);
     QSize sizeHint() const ;
-    void paintEvent ( QPaintEvent * ) ;
+    void paintEvent(QPaintEvent *) ;
 };
 #endif
