@@ -2,10 +2,10 @@
     This file is part of Rocs.
     Copyright 2011  Tomaz Canabrava <tomaz.canabrava@gmail.com>
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
+    This program is free software; you can redistribute it and/or
+    modify it under the terms of the GNU General Public License as
+    published by the Free Software Foundation; either version 2 of
+    the License, or (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -25,17 +25,17 @@
 
 class ListNode : public Data
 {
-  Q_OBJECT
-  public:
-    static DataPtr create(DataStructurePtr parent);
-    ListNode(DataStructurePtr parent);
+    Q_OBJECT
+public:
+    static DataPtr create(DataStructurePtr parent, int uniqueIdentifier, int dataType);
+    ListNode(DataStructurePtr parent, int uniqueIdentifier, int dataType);
     ~ListNode();
 
     boost::shared_ptr<ListNode> next() const;
 
-  public slots:
+public slots:
     QScriptValue front();
-    void pointTo(ListNode* to);
+    void pointTo(boost::shared_ptr<ListNode> to);
 
 
 };
